import * as plugins from "./smartnginx.plugins";
export let getBaseConfigString = () => {
	let baseConfig = plugins.smartstring.indent.normalize(`
		user www-data;
		worker_processes auto;
		pid /run/nginx.pid;

		events {
			worker_connections 768;
			# multi_accept on;
		}

		http {
			server_names_hash_bucket_size 128;

			##
			# Basic Settings
			##

			sendfile on;
			tcp_nopush on;
			tcp_nodelay on;
			keepalive_timeout 65;
			types_hash_max_size 2048;
			# server_tokens off;

			# server_names_hash_bucket_size 64;
			# server_name_in_redirect off;

			include /etc/nginx/mime.types;
			default_type application/octet-stream;

			##
			# SSL Settings
			##

			ssl_protocols TLSv1 TLSv1.1 TLSv1.2; # Dropping SSLv3, ref: POODLE
			ssl_prefer_server_ciphers on;

			##
			# Logging Settings
			##

			access_log /var/log/nginx/access.log;
			error_log /var/log/nginx/error.log;

			##
			# Gzip Settings
			##

			gzip on;
			gzip_disable "msie6";

			# gzip_vary on;
			# gzip_proxied any;
			# gzip_comp_level 6;
			# gzip_buffers 16 8k;
			# gzip_http_version 1.1;
			# gzip_types text/plain text/css application/json application/javascript text/xml application/xml application/xml+rss text/javascript;

			##
			# Virtual Host Configs
			##

			include /etc/nginx/conf.d/*.conf;
			include /etc/nginx/sites-enabled/*;
		}
		daemon off;
	`);
	return baseConfig;
}


export let getZoneConfigString = (zoneNameArg:string,destinationIpArg:string) => {
	let zoneConfig = plugins.smartstring.indent.normalize(`
		upstream ${zoneNameArg} {
			server ${destinationIpArg};
		}

		server {
			listen *:80 ;
			server_name ${zoneNameArg};
			rewrite        ^ https://${zoneNameArg}$request_uri? permanent;
		}

		server {
			listen *:443 ssl;
			server_name ${zoneNameArg};
			ssl_certificate /LE_CERTS/${zoneNameArg}/fullchain.pem;
			ssl_certificate_key /LE_CERTS/${zoneNameArg}/privkey.pem;

			location / {
				proxy_pass http://${zoneNameArg};
				include /etc/nginx/proxy_params;
			}
			location ~ /\.git {
				deny all;
			}
		}
	`);
	return zoneConfig;
};

